==> haskell-fdo-notify-0.3.1-850-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fdo-notify
version:              0.3.1
visibility:           public
id:                   fdo-notify-0.3.1-2hBVo5UbupGKV1boyMWwBz
key:                  fdo-notify-0.3.1-2hBVo5UbupGKV1boyMWwBz
license:              BSD-3-Clause
maintainer:           max.rabkin@gmail.com
author:               Max Rabkin
homepage:             http://bitbucket.org/taejo/fdo-notify/
synopsis:             Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.

category:             Desktop
abi:                  53856eb38640e66c1e38edde9f437188
exposed:              True
exposed-modules:      DBus.Notify
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fdo-notify
hs-libraries:         HSfdo-notify-0.3.1-2hBVo5UbupGKV1boyMWwBz
depends:
    base-4.17.2.1 containers-0.6.7 dbus-1.3.3-GdANdLtzP8i3k9U01Sr4iH

haddock-interfaces:   /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html:         /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fdo-notify-0.3.1-851-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fdo-notify
version:              0.3.1
visibility:           public
id:                   fdo-notify-0.3.1-J2ZRKUqRqGTKMDNePtqtO4
key:                  fdo-notify-0.3.1-J2ZRKUqRqGTKMDNePtqtO4
license:              BSD-3-Clause
maintainer:           max.rabkin@gmail.com
author:               Max Rabkin
homepage:             http://bitbucket.org/taejo/fdo-notify/
synopsis:             Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.

category:             Desktop
abi:                  44d87661f5d0cb49cda481e810b45f3d
exposed:              True
exposed-modules:      DBus.Notify
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fdo-notify
hs-libraries:         HSfdo-notify-0.3.1-J2ZRKUqRqGTKMDNePtqtO4
depends:
    base-4.17.2.1 containers-0.6.7 dbus-1.3.3-7m0AwE0r7NIE6fn6setqlv

haddock-interfaces:   /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html:         /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
